==> jc-1.4.0.tar.gz: soot/dava/internal/AST/ASTNode.h <==
// public abstract class soot.dava.internal.AST.ASTNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_AbstractUnit

#include "soot/AbstractUnit.h"

#ifndef _JC_soot_dava_internal_AST_ASTNode_H_
#define _JC_soot_dava_internal_AST_ASTNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTNode$sub_refs	_jc_soot_dava_internal_AST_ASTNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTNode$refs	_jc_soot_dava_internal_AST_ASTNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTNode$nonrefs	_jc_soot_dava_internal_AST_ASTNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTNode$object	_jc_soot_dava_internal_AST_ASTNode$object;

typedef struct _jc_soot_dava_internal_AST_ASTNode$fields_struct	_jc_soot_dava_internal_AST_ASTNode$fields_struct;
typedef const struct _jc_soot_dava_internal_AST_ASTNode$vmethods	_jc_soot_dava_internal_AST_ASTNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTNode$vtable	_jc_soot_dava_internal_AST_ASTNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTNode$vtype	_jc_soot_dava_internal_AST_ASTNode$vtype;

// Class fields structure
struct _jc_soot_dava_internal_AST_ASTNode$fields_struct {
	struct _jc_java_lang_String$object	*NEWLINE;
	struct _jc_java_lang_String$object	*TAB;
};
extern _jc_soot_dava_internal_AST_ASTNode$fields_struct _jc_soot_dava_internal_AST_ASTNode$class_fields;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTNode$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTNode$method$body__5ftoString$e125c7ea45be3ba5(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *);
extern void _jc_soot_dava_internal_AST_ASTNode$method$body__5ftoString$6d3bcf533292655d(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *, struct _jc_object *);
extern jboolean _jc_soot_dava_internal_AST_ASTNode$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *);
extern jboolean _jc_soot_dava_internal_AST_ASTNode$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *);
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTNode$method$get__5fSubBodies$9509491c71ac96ab(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *);
extern void _jc_soot_dava_internal_AST_ASTNode$method$perform__5fAnalysis$22b39eae4f6a8345(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
extern void _jc_soot_dava_internal_AST_ASTNode$method$perform__5fAnalysisOnSubBodies$69da530fdb259b86(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
extern void _jc_soot_dava_internal_AST_ASTNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$body__5ftoString$e125c7ea45be3ba5;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$body__5ftoString$6d3bcf533292655d;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$get__5fSubBodies$9509491c71ac96ab;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$perform__5fAnalysis$22b39eae4f6a8345;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$perform__5fAnalysisOnSubBodies$69da530fdb259b86;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTNode$vmethods {
	struct _jc_java_lang_String$object	*(*body__5ftoString$e125c7ea45be3ba5)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *);
	void	(*body__5ftoString$6d3bcf533292655d)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *, struct _jc_object *);
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *);
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *);
	struct _jc_object	*(*get__5fSubBodies$9509491c71ac96ab)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *);
	void	(*perform__5fAnalysis$22b39eae4f6a8345)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
	void	(*perform__5fAnalysisOnSubBodies$69da530fdb259b86)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTNode$sub_refs {
	struct _jc_object	*subBodies;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTNode$refs {
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTNode$object {
	_jc_soot_dava_internal_AST_ASTNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTNode$vtype _jc_soot_dava_internal_AST_ASTNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/AST/ASTNode.h <==
// public abstract class soot.dava.internal.AST.ASTNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_AbstractUnit

#include "soot/AbstractUnit.h"

#ifndef _JC_soot_dava_internal_AST_ASTNode_H_
#define _JC_soot_dava_internal_AST_ASTNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTNode$sub_refs	_jc_soot_dava_internal_AST_ASTNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTNode$refs	_jc_soot_dava_internal_AST_ASTNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTNode$nonrefs	_jc_soot_dava_internal_AST_ASTNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTNode$object	_jc_soot_dava_internal_AST_ASTNode$object;

typedef struct _jc_soot_dava_internal_AST_ASTNode$fields_struct	_jc_soot_dava_internal_AST_ASTNode$fields_struct;
typedef const struct _jc_soot_dava_internal_AST_ASTNode$vmethods	_jc_soot_dava_internal_AST_ASTNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTNode$vtable	_jc_soot_dava_internal_AST_ASTNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTNode$vtype	_jc_soot_dava_internal_AST_ASTNode$vtype;

// Class fields structure
struct _jc_soot_dava_internal_AST_ASTNode$fields_struct {
	struct _jc_java_lang_String$object	*NEWLINE;
	struct _jc_java_lang_String$object	*TAB;
};
extern _jc_soot_dava_internal_AST_ASTNode$fields_struct _jc_soot_dava_internal_AST_ASTNode$class_fields;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTNode$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTNode$method$body__5ftoString$e125c7ea45be3ba5(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTNode$method$body__5ftoString$6d3bcf533292655d(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_internal_AST_ASTNode$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_internal_AST_ASTNode$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTNode$method$get__5fSubBodies$9509491c71ac96ab(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTNode$method$perform__5fAnalysis$22b39eae4f6a8345(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTNode$method$perform__5fAnalysisOnSubBodies$69da530fdb259b86(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$body__5ftoString$e125c7ea45be3ba5;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$body__5ftoString$6d3bcf533292655d;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$get__5fSubBodies$9509491c71ac96ab;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$perform__5fAnalysis$22b39eae4f6a8345;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$perform__5fAnalysisOnSubBodies$69da530fdb259b86;
extern _jc_method _jc_soot_dava_internal_AST_ASTNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTNode$vmethods {
	struct _jc_java_lang_String$object	*(*body__5ftoString$e125c7ea45be3ba5)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*body__5ftoString$6d3bcf533292655d)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *) _JC_JCNI_ATTR;
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*get__5fSubBodies$9509491c71ac96ab)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *) _JC_JCNI_ATTR;
	void	(*perform__5fAnalysis$22b39eae4f6a8345)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
	void	(*perform__5fAnalysisOnSubBodies$69da530fdb259b86)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTNode$sub_refs {
	struct _jc_object	*subBodies;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTNode$refs {
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTNode$object {
	_jc_soot_dava_internal_AST_ASTNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTNode$vtype _jc_soot_dava_internal_AST_ASTNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTNode_H_ */
